cordova.define("com.sfexpress.bluetooth.BluetoothPlugin", function(require, exports, module) {

    var exec = require('cordova/exec');

    var BluetoothPlugin = function() {};

    var stringToArrayBuffer = function(str) {
        var ret = new Uint8Array(str.length);
        for (var i = 0; i < str.length; i++) {
            ret[i] = str.charCodeAt(i);
        }
        return ret.buffer;
    };

    var base64ToArrayBuffer = function(b64) {
        return stringToArrayBuffer(atob(b64));
    };

    function massageMessageNativeToJs(message) {
        if (message.CDVType == 'ArrayBuffer') {
            message = base64ToArrayBuffer(message.data);
        }
        return message;
    }

    // Cordova 3.6 doesn't unwrap ArrayBuffers in nested data structures
    // https://github.com/apache/cordova-js/blob/94291706945c42fd47fa632ed30f5eb811080e95/src/ios/exec.js#L107-L122
    function convertToNativeJS(object) {
        Object.keys(object).forEach(function (key) {
            var value = object[key];
            object[key] = massageMessageNativeToJs(value);
            if (typeof(value) === 'object') {
                convertToNativeJS(value);
            }
        });
    }

    //开始扫描
    BluetoothPlugin.startScan = function(seconds, success, failure) {
        var successWrapper = function(peripheral) {
                    convertToNativeJS(peripheral);
                    success(peripheral);
                };
        exec(successWrapper, failure, 'BluetoothPlugin', 'startScan', [seconds]);
    };

    //停止扫描
    BluetoothPlugin.stopScan = function(success, failure) {
        exec(success, failure, 'BluetoothPlugin', 'stopScan', []);
    };


    //初始化蓝牙适配器
    BluetoothPlugin.openBluetoothAdapter = function(success, failure){
        exec(success, failure, 'BluetoothPlugin', 'openBluetoothAdapter', []);
    };

    //连接蓝牙
    BluetoothPlugin.connect = function(deviceId, success, failure) {
        var successWrapper = function(peripheral) {
            convertToNativeJS(peripheral);
            success(peripheral);
        };
        exec(successWrapper, failure, 'BluetoothPlugin', 'connect', [deviceId]);
    };

    //断开连接
    BluetoothPlugin.disconnect = function(success, failure) {
        exec(success, failure, 'BluetoothPlugin', 'disconnect', []);
    };

    //写入数据到蓝牙
    BluetoothPlugin.write = function(data, success, failure) {
        exec(success, failure, 'BluetoothPlugin', 'write', [data]);
    };


    BluetoothPlugin.read = function(device_id, service_uuid, characteristic_uuid, success, failure) {

    };

    BluetoothPlugin.readRSSI = function(device_id, success, failure) {

    };

    BluetoothPlugin.writeWithoutResponse = function(device_id, service_uuid, characteristic_uuid, data, success, failure) {

    };

    BluetoothPlugin.startNotification = function(device_id, service_uuid, characteristic_uuid, success, failure) {

    };

    BluetoothPlugin.stopNotifcation = function(device_id, service_uuid, characteristic_uuid, success, failure) {

    };

    BluetoothPlugin.isEnabled = function(success, failure) {

    };

    BluetoothPlugin.isConnected = function(device_id, success, failure) {

    };

    BluetoothPlugin.showBluetoothSettings = function(success, failure) {

    };

    BluetoothPlugin.startStateNotifications = function(success, failure) {

    };

    BluetoothPlugin.stopStateNotifications = function(success, failure) {

    }

    module.exports = BluetoothPlugin;

});